(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     38498,       1282]
NotebookOptionsPosition[     31374,       1078]
NotebookOutlinePosition[     31833,       1096]
CellTagsIndexPosition[     31790,       1093]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["MathCode setup test, v4 (2010-08-19)", "Title",
 CellChangeTimes->{{3.4746954908109636`*^9, 3.4746955018738885`*^9}, {
  3.491069232389038*^9, 3.4910692405542803`*^9}, {3.491220782608181*^9, 
  3.491220790935544*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Always start MathCode from Start Menu.",
  FontWeight->"Bold"],
 "\nThis Mathematica notebook tests the contents of Licensing directory and \
your MathCode setup in order to detect configuration errors. These errors \
occur if something unusual happens with your installation of your operating \
system, Mathematica, C++ or F90 compiler(s), MathCode or other software. \
Please read Release Notes, they explain most of these issues. \nPlease \
execute whole notebook, ",
 StyleBox["SAVE",
  FontWeight->"Bold"],
 " this notebook and send ",
 StyleBox["as attachment",
  FontWeight->"Bold"],
 " to support@mathcore.com.\nDo not cut-and-paste the text in this notebook \
into your e-mail text.\nIf you are ",
 StyleBox["concerned about privacy",
  FontWeight->"Bold"],
 " of information contained here you can remove any cells you do not like; \
you can also convert the notebook into a PDF file. \nWe use this notebook ",
 StyleBox["only",
  FontWeight->"Bold"],
 " to detect configuration errors in your installation of MathCode.  \n(C) \
2010, MathCore Engineerng AB. "
}], "Text",
 CellChangeTimes->{{3.4746954853888807`*^9, 3.4746954875295877`*^9}, {
  3.474695845979179*^9, 3.474695846447941*^9}}],

Cell[CellGroupData[{

Cell["Before you start", "Subtitle"],

Cell[TextData[{
 StyleBox["Always start MathCode from Start Menu.",
  FontWeight->"Bold"],
 "\nFor MathCode C++ users: If you are trying to resolve a compiler \
configuration problem (BuildCode[] does not work) please try running in each  \
mode separately - with (default) \"mingw32\" first. If you use MicroSoft \
Visual C++ you should reinstall MathCode. So you get two notebooks."
}], "Text",
 CellChangeTimes->{{3.474695882323859*^9, 3.4746959078557625`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check version and license", "Subtitle"],

Cell[TextData[StyleBox["Always start MathCode from Start Menu.",
 FontWeight->"Bold"]], "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Should normally tell ",
 StyleBox["MathCode (version) loaded.",
  FontWeight->"Bold"],
 " If it does (produce any errors) not then MathCode.m is missing in \
Mathematicas path. See  \
ToFileName[{$TopDirectory,\"AddOns\",\"Applications\"},\"MathCode.m\"] below. \
May be several Mathematica  installations on the same computer. MathCode \
Version number should be the same  as in setup executable.\n    "
}], "Text",
 CellChangeTimes->{3.49096108645632*^9, 3.491101715760006*^9}],

Cell[BoxData["$MCKey"], "Input"],

Cell["\<\
Tells user name specified during installation. It does not affect execution.  \
  \
\>", "Text"],

Cell[BoxData["$MCKeyData"], "Input"],

Cell["\<\
Tells organization name specified during installation. It does not affect \
execution.    \
\>", "Text"],

Cell[BoxData[
 RowBox[{"$MCLicenseID", "//", "FullForm"}]], "Input",
 CellChangeTimes->{3.491069456181282*^9}],

Cell["\<\
Tells license ID  specified during installation. It is compared with data \
encoded in license key delivered from MathCore by e-mail. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"StringPosition", "[", 
     RowBox[{"$MCLicenseID", ",", "\"\<O\>\""}], "]"}], "\[NotEqual]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"Print", "[", "\"\<Bad license, letter O is present\>\"", "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"StringMatchQ", "[", 
    RowBox[{"$MCLicenseID", ",", 
     RowBox[{
     "RegularExpression", "[", 
      "\"\<MC0\\\\d\\\\d\\\\d\\-\\\\d\\\\d\\\\d\\\\d\>\"", "]"}]}], "]"}], 
   ",", "Null", ",", 
   RowBox[{
   "Print", "[", "\"\<Bad license, does not match the pattern\>\"", "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"$F90License", "=", 
  RowBox[{
   RowBox[{"StringTake", "[", 
    RowBox[{"$MCLicenseID", ",", 
     RowBox[{"{", "6", "}"}]}], "]"}], "\[Equal]", "\"\<1\>\""}]}]], "Input",
 CellChangeTimes->{{3.491101805367508*^9, 3.49110181569*^9}}],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"$F90License", " ", "\[Equal]", " ", 
    RowBox[{"(", 
     RowBox[{
     "MathCode`$MathCodeDefaultLanguage", " ", "==", " ", 
      "\"\<Fortran90\>\""}], ")"}]}], ",", 
   RowBox[{"Print", "[", "\"\<OK\>\"", "]"}], ",", 
   RowBox[{"Print", "[", "\"\<Wrong target language\>\"", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.491101805367508*^9, 3.491101820604538*^9}, {
   3.491101880132111*^9, 3.491101913195902*^9}, 3.49122080889609*^9}],

Cell["\<\
Whether this license is good for F90, and if this fact matches the license \
number. If not, you registered wrong variant of MathCode.\
\>", "Text",
 CellChangeTimes->{{3.491101805367508*^9, 3.491101812064458*^9}, {
  3.4911018536975517`*^9, 3.491101865176424*^9}}],

Cell[BoxData[
 RowBox[{"$MachineID", "//", "FullForm"}]], "Input"],

Cell["\<\
Tells license Machine  ID  of actual computer. It is compared  with data \
encoded in  license key delivered from MathCore by e-mail. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"$MathCodeReleaseNumber", "//", "FullForm"}]], "Input"],

Cell["\<\
Tells the internal release number which MathCore increments with each new \
release.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"$MathCodeVersionNumber", "//", "FullForm"}]], "Input"],

Cell["\<\
Tells the internal version  number which MathCore increments with each new \
version.  \
\>", "Text"],

Cell[BoxData["$Version"], "Input"],

Cell[TextData[{
 "Tells the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  version  number.  "
}], "Text",
 CellChangeTimes->{3.491100918133009*^9}],

Cell[BoxData[
 RowBox[{"$MCWindows", "=", 
  RowBox[{"$SystemID", "\[Equal]", "\"\<Windows\>\""}]}]], "Input",
 CellChangeTimes->{{3.491101025524544*^9, 3.491101075959792*^9}, 
   3.49110173950413*^9}],

Cell["Tells whether we assume Windows machine during this test.  ", "Text",
 CellChangeTimes->{
  3.491100918133009*^9, {3.491101939735282*^9, 3.491101957123822*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.491101925892899*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check where things are installed ", "Subtitle"],

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"If", "[", 
   RowBox[{"$MCWindows", ",", "\"\<C:\\\\\>\"", ",", "\"\</usr/local\>\""}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4909612290202007`*^9, 3.4909612539629507`*^9}, {
  3.491101143042297*^9, 3.4911011807252693`*^9}, {3.491101218712884*^9, 
  3.491101235476783*^9}}],

Cell["\<\
Check what is installed in Program Files (makes sense on Windows only)\
\>", "Text",
 CellChangeTimes->{{3.491069554897461*^9, 3.491069605795867*^9}, {
  3.491101255060793*^9, 3.49110126295695*^9}}],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FileInformation", "[", "#", "]"}], ",", 
      RowBox[{"FileDate", "[", "#", "]"}]}], "}"}], "&"}], ",", 
   RowBox[{"FileNames", "[", "\"\<Pro*\>\"", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "%", "]"}], "\[Equal]", "1"}]], "Input"],

Cell["\<\
If it is false (on some Asian or French) Windows computers Progra~1 may point \
to different place. Reinstall Mathcode outside Progra* directories.  \
\>", "Text",
 CellChangeTimes->{{3.491069621446725*^9, 3.491069623051629*^9}}],

Cell[BoxData[
 RowBox[{"FileInformation", "[", "\"\<Progra~1\>\"", "]"}]], "Input"],

Cell["\<\
Check Mathematica installation
\
\>", "Text",
 CellChangeTimes->{{3.491101277053935*^9, 3.4911012845868*^9}}],

Cell[BoxData["$TopDirectory"], "Input"],

Cell[BoxData["$HomeDirectory"], "Input",
 CellChangeTimes->{{3.491101369975252*^9, 3.4911013784154243`*^9}}],

Cell[BoxData[
 RowBox[{"x", "=", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{"$MCWindows", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "$TopDirectory", ",", "\"\<AddOns\>\"", ",", "\"\<Applications\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "$HomeDirectory", ",", "\"\<.Mathematica\>\"", ",", 
        "\"\<Applications\>\""}], "}"}]}], "\[IndentingNewLine]", " ", "]"}], 
    ",", "\"\<MathCode.m\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49110141124123*^9, 3.491101508460436*^9}}],

Cell[BoxData[
 RowBox[{"FileInformation", "[", "x", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
   "Print", "[", 
    "\"\<Probably Mathcode was installed in a different place, or \
uninstalled, or not installec at all\>\"", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"x", ",", "\"\<Text\>\""}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{3.49110153208922*^9}],

Cell["\<\
The values in this file should point to existing directories. This file makes \
possible to write Needs[\"MathCode`\"]. The details are checked later on.
    \
\>", "Text",
 CellChangeTimes->{{3.49110198660417*^9, 3.491102007955118*^9}}],

Cell[BoxData["$MCRoot"], "Input",
 CellChangeTimes->{{3.4911015445681334`*^9, 3.4911015493631887`*^9}}],

Cell[BoxData["MathCode`$MCRoot"], "Input"],

Cell[BoxData["MathCode`$MathCodeShortPath"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "\[NotEqual]", "%"}], ")"}], "||", 
     RowBox[{"(", 
      RowBox[{"%%%", "\[NotEqual]", "%"}], ")"}]}], ",", " ", 
    RowBox[{
    "Print", "[", 
     "\"\<MathCode context is not established, or MathCode is not correctly \
loaded.\>\"", "]"}]}], "]"}], "\[IndentingNewLine]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check licensing cache", "Subtitle"],

Cell[BoxData[
 RowBox[{"ToFileName", "[", 
  RowBox[{"{", 
   RowBox[{"MathCode`$MCRoot", ",", "\"\<Licensing\>\""}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "$MCRoot", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FileNames", "[", "]"}]], "Input"],

Cell[TextData[{
 "\nIf installation is correct, ",
 StyleBox["mathcode.lic",
  FontWeight->"Bold"],
 " must be here. Any ",
 StyleBox["*.mh",
  FontWeight->"Bold"],
 " files should not be here."
}], "Text",
 CellChangeTimes->{{3.4911020349476213`*^9, 3.4911020353236227`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<MathCode.lic\>\"", ",", "\"\<List\>\""}], "]"}], "//", 
   "FullForm"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FileInformation", "[", "#", "]"}], ",", 
        RowBox[{"FileDate", "[", "#", "]"}]}], "}"}], "&"}], ",", 
     RowBox[{"FileNames", "[", "]"}]}], "]"}], "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.491069845542081*^9, 3.4910698554185*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{"{", 
     RowBox[{"MathCode`$MCRoot", ",", "\"\<Licensing\>\""}], "}"}], "]"}], 
   "]"}], "//", "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Directory", "[", "]"}], "//", "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Directory", "[", "]"}], "!=", 
    RowBox[{"ToFileName", "[", 
     RowBox[{
      RowBox[{"{", "MathCode`$MCRoot", "}"}], ",", "\"\<Licensing\>\""}], 
     "]"}]}], ",", 
   RowBox[{
   "Print", "[", 
    "\"\<The Licensing directory has not been created. MathCode has been \
installed without license key specified. See insttructions how to put license \
key in this directory in an e-meil containing the license key\>\"", "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FileNames", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FileInformation", "[", "#", "]"}], ",", 
       RowBox[{"FileDate", "[", "#", "]"}]}], "}"}], "&"}], ",", 
    RowBox[{"FileNames", "[", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"FullForm", "[", 
      RowBox[{"Import", "[", 
       RowBox[{"#1", ",", "\"\<Text\>\""}], "]"}], "]"}], ")"}], "&"}], ",", 
   RowBox[{"FileNames", "[", "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 "The key file usually named like ",
 StyleBox["234.mkey ",
  FontWeight->"Bold"],
 "or",
 " ",
 StyleBox["234.key",
  FontWeight->"Bold"],
 " should contain at least ",
 StyleBox["256",
  FontWeight->"Bold"],
 " bytes and no newlines in the middle. If not then it was wronlgy copied \
from e-mail attachment to this place. A message will be produced when you \
attempt to compile.\n       The index.m  should look like ",
 StyleBox["\"{\\\"6139-68937-93139\\\" -> \\\"234.key\\\"}\\n\"",
  FontWeight->"Bold"],
 ". If not, then ",
 StyleBox["$MachineID",
  FontWeight->"Bold"],
 " or  ",
 StyleBox["$MCLicenseID",
  FontWeight->"Bold"],
 " were wrong somewhere above. \n    "
}], "Text",
 CellChangeTimes->{{3.491069958485705*^9, 3.491069965134694*^9}}],

Cell[BoxData[
 RowBox[{"useKeyFile", "=", 
  RowBox[{
   RowBox[{"FileNames", "[", "\"\<*.*key\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.491069948778255*^9}],

Cell["\<\
This should be the file you got from e - mail. Normally it is just one file. \
Any other  license key files should be better removed (except of shared \
installation case)
\
\>", "Text",
 CellChangeTimes->{{3.4911021355658283`*^9, 3.49110219440415*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check character codes ", "Subtitle"],

Cell["These tests return True on windows development computers. ", "Text"],

Cell[BoxData[
 StyleBox["$CharacterEncoding", "MR"]], "Input"],

Cell[BoxData[
 StyleBox["$SystemCharacterEncoding", "MR"]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["$CharacterEncoding", "MR"], 
  StyleBox["==", "MR"], "\"\<WindowsANSI\>\""}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox["$SystemCharacterEncoding", "MR"], 
  StyleBox["==", "MR"], "\"\<WindowsANSI\>\""}]], "Input"],

Cell[BoxData[
 RowBox[{"esca", "=", 
  "\"\<\\q\\w\\e(\\r)(\\t)\\y\\u\\i\\o\\p\\a\\s\\d(\\f)\\g\\h\\j\\k\\l\\z\\x\\\
c\\v(\\b)\\n\\m\\Q\n\\W\\E\\R\\T\\Y\\U\\I\\O\\P\\A\\S\\D\\F\\G\\H\\J\\K\\L\\Z\
\\X\\C\\V\\B\\N\\M\>\""}]], "Input"],

Cell[BoxData[
 RowBox[{"esca", "==", 
  "\"\<\\\\q\\\\w\\\\e(\\r)(\\t)\\\\y\\\\u\\\\i\\\\o\\\\p\\\\a\\\\s\\\\d(\\f)\
\\\\g\\\\h\\\\j\\\\k\\\\l\\\\z\\\\x\\\\c\\\\v(\.08)\\n\\\\m\\\\Q \\\\W\\\\E\\\
\\R\\\\T\\\\Y\\\\U\\\\I\\\\O\\\\P\\\\A\\\\S\\\\D\\\\F\\\\G\\\\H\\\\J\\\\K\\\\\
L\\\\Z\\\\X\\\\C\\\\V\\\\B\\\\N\\\\M\>\""}]], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check MathLink", "Subtitle"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"StringPosition", "[", 
       RowBox[{"$SystemID", ",", "\"\<Windows\>\""}], "]"}], "=!=", 
      RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"addTwoStr", "=", 
      RowBox[{
      "MathCode`$DevelopersKitsDirectoryFullPath", "<>", 
       "\"\<\\\\..\\\\PrebuiltExamples\\\\addtwo.exe\>\""}]}], ",", 
     RowBox[{"addTwoStr", "=", 
      RowBox[{
      "MathCode`$DevelopersKitsDirectoryFullPath", "<>", 
       "\"\</../PrebuiltExamples/addtwo\>\""}]}]}], "]"}], ";"}]}]], "Input"],

Cell["Missing file is evidence of non-standard paths to MathLink", "Text"],

Cell[BoxData[
 RowBox[{"FileInformation", "[", "addTwoStr", "]"}]], "Input"],

Cell["\<\
Failure to install this mathlink is evidence of firewall preventing process \
communication\
\>", "Text"],

Cell[BoxData[
 RowBox[{"linkAddTwo", "=", 
  RowBox[{"Install", "[", "addTwoStr", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"AddTwo", "[", 
  RowBox[{"2", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Uninstall", "[", "linkAddTwo", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check code generator", "Subtitle"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmplink", "=", 
   RowBox[{"Install", "[", 
    RowBox[{"$MCRoot", "<>", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"StringPosition", "[", 
         RowBox[{"$SystemID", ",", "\"\<Windows\>\""}], "]"}], "=!=", 
        RowBox[{"{", "}"}]}], ",", "\"\<\\\\System\\\\om.exe\>\"", ",", 
       "\"\</System/om\>\""}], "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"LinkPatterns", "[", "tmplink", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Length", "[", 
      RowBox[{"LinkPatterns", "[", "tmplink", "]"}], "]"}], "\[Equal]", "9"}],
     ",", "OK", ",", 
    RowBox[{"Print", "[", "\"\<Missing patterns in OM.EXE\>\"", "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"exid", "=", 
  RowBox[{"extractid", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"MathCode`$MCRoot", ",", "\"\<Licensing\>\""}], "}"}], ",", 
     "useKeyFile"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491102315981938*^9, 3.491102318299652*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"exid", " ", "\[Equal]", " ", "$MachineID"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.491102322437832*^9, 3.491102336151267*^9}}],

Cell[TextData[{
 "If ",
 StyleBox["False",
  FontWeight->"Bold"],
 " - you have wrong license key file.\n   "
}], "Text",
 CellChangeTimes->{{3.4911023385452538`*^9, 3.4911023772939367`*^9}}],

Cell[BoxData[
 RowBox[{"licverify", "[", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"MathCode`$MCRoot", ",", "\"\<Licensing\>\""}], "}"}], ",", 
    "useKeyFile"}], "]"}], "]"}]], "Input"],

Cell[TextData[{
 "If not ",
 StyleBox["1",
  FontWeight->"Bold"],
 " your license expired"
}], "Text",
 CellChangeTimes->{{3.491102384460705*^9, 3.491102394940404*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"$DemosDir", "=", 
   RowBox[{"If", "[", 
    RowBox[{"$F90License", ",", "\"\<DemosF90\>\"", ",", "\"\<Demos\>\""}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4910700833108873`*^9, 3.491070162928008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{
   "$MCRoot", "<>", "\"\</\>\"", "<>", "$DemosDir", "<>", 
    "\"\</SimplestExample\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.491070167343381*^9, 3.491070192705284*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Directory", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<G.mci\>\"", ",", "\"\<model Global;  packages \\\"MathCode`\\\";\>\"",
     ",", "\"\<Text\>\""}], "]"}], "\n"}]], "Input"],

Cell["\<\

This must end with dead connection. Don't care.\
\>", "Text",
 CellChangeTimes->{{3.491102472055397*^9, 3.4911024836830997`*^9}}],

Cell[BoxData[
 RowBox[{"CompileInternal", "[", 
  RowBox[{"\"\<G.mci\>\"", ",", "\"\<G.mm\>\"", ",", "\"\<G.er\>\"", ",", 
   RowBox[{"If", "[", 
    RowBox[{
    "$F90License", ",", "\"\<-l Fortran90\>\"", ",", "\"\<-l C++\>\""}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.491070229177425*^9, 3.4910702575961437`*^9}, 
   3.491070344163948*^9}],

Cell[BoxData[
 RowBox[{"Uninstall", "[", "tmplink", "]"}]], "Input"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.4910703867619123`*^9, 3.4910704300290813`*^9}, 
   3.491070484980933*^9}],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check Windows language version", "Subtitle"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"$MCRoot", "<>", "\"\</Demos\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<ver > x.txt\>\"", "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Run", "[", 
   "\"\<START /WAIT REGEDIT /E \\\"x.txt\\\" \
\\\"HKEY_LOCAL_MACHINE\\\\Software\\\\Microsoft\\\\Windows \
NT\\\\CurrentVersion\\\\WOW\\\\boot.description\\\"\>\"", "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", 
     StyleBox["\"\<UnicodeText\>\"", "MR"]}], "]"}], ",", "\"\<\\n\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check compliers", "Subtitle"],

Cell["\<\
What you get here depends on MathCodeConfig.m, depends on whether you  done \
instructions from  Release Notes, and whether you have all necessary or \
optional  C++ compilers.
    \
\>", "Text"],

Cell[BoxData["$DefaultCompilers"], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"$CompilerDefinitions", "//", "FullForm"}]}]], "Input"],

Cell[BoxData["$SystemID"], "Input"],

Cell[BoxData["$System"], "Input"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "$MCRoot", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Environment", "[", "\"\<COMSPEC\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Environment", "[", "\"\<MSDKBAT\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Environment", "[", "\"\<MCSTARTBAT\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"$MCWindows", ",", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<StartMathCode.bat\>\"", ",", "\"\<Text\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.491102569637022*^9, 3.4911025850358458`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{"$MCWindows", ",", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<StartMathCode.bat\>\"", ",", "\"\<Text\>\""}], "]"}]}], 
   "]"}], "//", "FullForm"}]], "Input",
 CellChangeTimes->{{3.491102591495829*^9, 3.491102597707056*^9}}],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"$MCWindows", ",", 
   RowBox[{"noquotes", "=", 
    RowBox[{"StringDrop", "[", 
     RowBox[{
      RowBox[{"StringDrop", "[", 
       RowBox[{
        RowBox[{"Environment", "[", "\"\<MCSTARTBAT\>\"", "]"}], ",", "1"}], 
       "]"}], ",", 
      RowBox[{"-", "1"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.491102593824853*^9, 3.491102599821529*^9}}],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"$MCWindows", ",", 
   RowBox[{"Import", "[", 
    RowBox[{"noquotes", ",", "\"\<Text\>\""}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.491102608003469*^9, 3.491102614481372*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{"$MCWindows", ",", 
    RowBox[{"Import", "[", 
     RowBox[{"noquotes", ",", "\"\<Text\>\""}], "]"}]}], "]"}], "//", 
  "FullForm"}]], "Input",
 CellChangeTimes->{{3.491102609514134*^9, 3.491102618716165*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"DeleteFile", "::", "\"\<nffil\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"On", "[", 
  RowBox[{"DeleteFile", "::", "\"\<nffil\>\""}], "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Run", "[", "\"\<make -v > x.txt\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
  "FullForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}]], "Input"],

Cell["\<\

Should report GNU Make here\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Run", "[", "\"\<set > x.txt\>\"", "]"}], ";", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"\"\<x.txt\>\"", ",", "\"\<Lines\>\""}], "]"}], "//", 
    "FullForm"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Run", "[", "\"\<assoc .h> x.txt\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Run", "[", "\"\<assoc  .cpp>> x.txt\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Run", "[", "\"\<assoc  .vcproj>> x.txt\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"\"\<x.txt\>\"", ",", "\"\<Lines\>\""}], "]"}], "//", 
    "FullForm"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<nmake /X- > x.txt\>\"", "]"}], ";", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
   "FullForm"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<cl 2> x.txt\>\"", "]"}], ";", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
   "FullForm"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<gcc -v 2> x.txt\>\"", "]"}], ";", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
   "FullForm"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Run", "[", "\"\<g95 -v 2> x.txt\>\"", "]"}], ";", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
    "FullForm"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.474695793462209*^9, 3.4746957948372445`*^9}, 
   3.491220838926309*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<type -p g95 > x.txt\>\"", "]"}], ";", 
  RowBox[{"FileInformation", "[", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491102696873411*^9, 3.491102720608426*^9}, {
  3.491102845408905*^9, 3.491102891708213*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<ifort -v 2> x.txt\>\"", "]"}], ";", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "//", 
   "FullForm"}]}]], "Input",
 CellChangeTimes->{{3.491220842886916*^9, 3.491220846564315*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", "\"\<type -p ifort > x.txt\>\"", "]"}], ";", 
  RowBox[{"FileInformation", "[", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<x.txt\>\"", ",", "\"\<Text\>\""}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491102696873411*^9, 3.491102720608426*^9}, {
   3.491102845408905*^9, 3.491102891708213*^9}, 3.4912208794872217`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.491102918040525*^9, 3.491102921258794*^9}}],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", "\"\<x.txt\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check normal BuildCode", "Subtitle"],

Cell["SetDirectory[$MCRoot<>\"/Demos\"];", "Input",
 CellChangeTimes->{3.491103171495284*^9}],

Cell["addtwo[Real a_,Real b_] -> Real := Module[{},a+b]", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"multint", "[", 
    RowBox[{
     RowBox[{"Integer", " ", "a_"}], ",", 
     RowBox[{"Integer", " ", "b_"}]}], "]"}], " ", "->", " ", "Integer"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"a", "*", "b"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.491220919830452*^9, 3.491220932260254*^9}}],

Cell[BoxData[
 RowBox[{"??", "addtwo"}]], "Input"],

Cell[TextData[{
 "Report about path without slashes is evidence of Japanses or Spanish \
Windows. Modify  ",
 StyleBox["MPREP=$(subst \\\\,\\,$(MPREP2))",
  FontWeight->"Bold"],
 "  to ",
 StyleBox["MPREP=$(MPREP2)",
  FontWeight->"Bold"],
 " in ",
 StyleBox["mingw32.mak",
  FontWeight->"Bold"],
 "\n"
}], "Text"],

Cell["BuildCode[]", "Input"],

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<*\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"\"\<Global.cmd\>\"", ",", "\"\<Lines\>\""}], "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"\"\<Global.clog\>\"", ",", "\"\<Lines\>\""}], "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"link1", "=", 
   RowBox[{"Install", "[", "\"\<Globalml.exe\>\"", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"??", "addtwo"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Uninstall", "[", "link1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"??", "addtwo"}]}]], "Input"],

Cell["InstallCode[];", "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"??", "addtwo"}]}]], "Input"],

Cell["\<\
addtwo[2.,2.]==4
\
\>", "Input",
 CellChangeTimes->{{3.491220937109713*^9, 3.491220944765023*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"multint", "[", 
   RowBox[{"214748", ",", "214748"}], "]"}], "==", 
  RowBox[{"-", "1127936752"}]}]], "Input",
 CellChangeTimes->{{3.4912209783208323`*^9, 3.491221013410441*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "InputString", "[", 
    "\"\<In the following dialogs (if they appear) press: Cancel Cancel \
OK\>\"", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.491103259793797*^9, 3.491103267212302*^9}}],

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<*\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Run", "[", "\"\<./Globalml.exe\>\"", "]"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.491070998685007*^9, 3.491071002023736*^9}, {
  3.491103217796225*^9, 3.491103222083352*^9}, {3.49110343668147*^9, 
  3.491103440703703*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Run", "[", 
   RowBox[{
    RowBox[{"FileNames", "[", "\"\<./Globalml.exe\>\"", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], "*)"}]], "Input",
 CellChangeTimes->{{3.4910710046339912`*^9, 3.491071007646987*^9}}],

Cell["CleanMathCodeFiles[Confirm -> False, CleanAllBut -> {}];", "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1048, 831},
WindowMargins->{{89, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 223, 3, 172, "Title"],
Cell[793, 27, 1235, 27, 299, "Text"],
Cell[CellGroupData[{
Cell[2053, 58, 36, 0, 65, "Subtitle"],
Cell[2092, 60, 464, 8, 109, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2593, 73, 45, 0, 65, "Subtitle"],
Cell[2641, 75, 95, 1, 37, "Text"],
Cell[2739, 78, 74, 1, 38, "Input"],
Cell[2816, 81, 497, 10, 109, "Text"],
Cell[3316, 93, 32, 0, 38, "Input"],
Cell[3351, 95, 106, 3, 37, "Text"],
Cell[3460, 100, 36, 0, 38, "Input"],
Cell[3499, 102, 114, 3, 37, "Text"],
Cell[3616, 107, 110, 2, 38, "Input"],
Cell[3729, 111, 158, 3, 61, "Text"],
Cell[3890, 116, 295, 8, 38, "Input"],
Cell[4188, 126, 365, 11, 64, "Input"],
Cell[4556, 139, 259, 6, 38, "Input"],
Cell[4818, 147, 505, 12, 64, "Input"],
Cell[5326, 161, 275, 5, 61, "Text"],
Cell[5604, 168, 66, 1, 38, "Input"],
Cell[5673, 171, 158, 3, 61, "Text"],
Cell[5834, 176, 78, 1, 38, "Input"],
Cell[5915, 179, 110, 3, 37, "Text"],
Cell[6028, 184, 78, 1, 38, "Input"],
Cell[6109, 187, 111, 3, 37, "Text"],
Cell[6223, 192, 34, 0, 38, "Input"],
Cell[6260, 194, 157, 6, 37, "Text"],
Cell[6420, 202, 201, 4, 38, "Input"],
Cell[6624, 208, 166, 2, 37, "Text"],
Cell[6793, 212, 87, 1, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6917, 218, 53, 0, 65, "Subtitle"],
Cell[6973, 220, 57, 1, 38, "Input"],
Cell[7033, 223, 341, 7, 38, "Input"],
Cell[7377, 232, 208, 4, 37, "Text"],
Cell[7588, 238, 282, 8, 38, "Input"],
Cell[7873, 248, 89, 2, 38, "Input"],
Cell[7965, 252, 239, 4, 61, "Text"],
Cell[8207, 258, 83, 1, 38, "Input"],
Cell[8293, 261, 119, 4, 61, "Text"],
Cell[8415, 267, 39, 0, 38, "Input"],
Cell[8457, 269, 108, 1, 38, "Input"],
Cell[8568, 272, 582, 15, 114, "Input"],
Cell[9153, 289, 68, 1, 38, "Input"],
Cell[9224, 292, 273, 8, 114, "Input"],
Cell[9500, 302, 174, 5, 64, "Input"],
Cell[9677, 309, 247, 5, 85, "Text"],
Cell[9927, 316, 103, 1, 38, "Input"],
Cell[10033, 319, 42, 0, 38, "Input"],
Cell[10078, 321, 53, 0, 38, "Input"],
Cell[10134, 323, 407, 12, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10578, 340, 41, 0, 65, "Subtitle"],
Cell[10622, 342, 144, 4, 38, "Input"],
Cell[10769, 348, 71, 1, 38, "Input"],
Cell[10843, 351, 57, 1, 38, "Input"],
Cell[10903, 354, 276, 9, 61, "Text"],
Cell[11182, 365, 186, 5, 64, "Input"],
Cell[11371, 372, 413, 11, 64, "Input"],
Cell[11787, 385, 220, 6, 38, "Input"],
Cell[12010, 393, 88, 2, 38, "Input"],
Cell[12101, 397, 529, 14, 139, "Input"],
Cell[12633, 413, 57, 1, 38, "Input"],
Cell[12693, 416, 309, 9, 64, "Input"],
Cell[13005, 427, 270, 8, 38, "Input"],
Cell[13278, 437, 770, 24, 132, "Text"],
Cell[14051, 463, 202, 5, 38, "Input"],
Cell[14256, 470, 263, 6, 85, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14556, 481, 42, 0, 65, "Subtitle"],
Cell[14601, 483, 74, 0, 37, "Text"],
Cell[14678, 485, 62, 1, 38, "Input"],
Cell[14743, 488, 68, 1, 38, "Input"],
Cell[14814, 491, 123, 3, 38, "Input"],
Cell[14940, 496, 129, 3, 38, "Input"],
Cell[15072, 501, 232, 4, 64, "Input"],
Cell[15307, 507, 329, 5, 93, "Input"],
Cell[15639, 514, 45, 0, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15721, 519, 34, 0, 65, "Subtitle"],
Cell[15758, 521, 628, 16, 139, "Input"],
Cell[16389, 539, 74, 0, 37, "Text"],
Cell[16466, 541, 76, 1, 38, "Input"],
Cell[16545, 544, 115, 3, 37, "Text"],
Cell[16663, 549, 100, 2, 38, "Input"],
Cell[16766, 553, 82, 2, 38, "Input"],
Cell[16851, 557, 71, 1, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16959, 563, 40, 0, 65, "Subtitle"],
Cell[17002, 565, 435, 12, 114, "Input"],
Cell[17440, 579, 71, 1, 38, "Input"],
Cell[17514, 582, 319, 9, 64, "Input"],
Cell[17836, 593, 316, 8, 38, "Input"],
Cell[18155, 603, 183, 4, 64, "Input"],
Cell[18341, 609, 191, 6, 61, "Text"],
Cell[18535, 617, 219, 6, 38, "Input"],
Cell[18757, 625, 168, 6, 37, "Text"],
Cell[18928, 633, 268, 6, 64, "Input"],
Cell[19199, 641, 250, 6, 38, "Input"],
Cell[19452, 649, 93, 2, 64, "Input"],
Cell[19548, 653, 193, 5, 64, "Input"],
Cell[19744, 660, 140, 4, 61, "Text"],
Cell[19887, 666, 356, 8, 38, "Input"],
Cell[20246, 676, 68, 1, 38, "Input"],
Cell[20317, 679, 122, 2, 38, "Input"],
Cell[20442, 683, 45, 0, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20524, 688, 50, 0, 65, "Subtitle"],
Cell[20577, 690, 108, 2, 38, "Input"],
Cell[20688, 694, 113, 3, 64, "Input"],
Cell[20804, 699, 140, 4, 38, "Input"],
Cell[20947, 705, 114, 3, 64, "Input"],
Cell[21064, 710, 260, 7, 114, "Input"],
Cell[21327, 719, 211, 6, 38, "Input"],
Cell[21541, 727, 75, 1, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21653, 733, 35, 0, 65, "Subtitle"],
Cell[21691, 735, 205, 5, 85, "Text"],
Cell[21899, 742, 43, 0, 38, "Input"],
Cell[21945, 744, 112, 2, 64, "Input"],
Cell[22060, 748, 35, 0, 38, "Input"],
Cell[22098, 750, 33, 0, 38, "Input"],
Cell[22134, 752, 71, 1, 38, "Input"],
Cell[22208, 755, 78, 1, 38, "Input"],
Cell[22289, 758, 78, 1, 38, "Input"],
Cell[22370, 761, 81, 1, 38, "Input"],
Cell[22454, 764, 252, 6, 38, "Input"],
Cell[22709, 772, 285, 7, 38, "Input"],
Cell[22997, 781, 409, 11, 38, "Input"],
Cell[23409, 794, 230, 5, 38, "Input"],
Cell[23642, 801, 267, 7, 38, "Input"],
Cell[23912, 810, 323, 9, 89, "Input"],
Cell[24238, 821, 242, 7, 64, "Input"],
Cell[24483, 830, 75, 1, 38, "Input"],
Cell[24561, 833, 52, 3, 61, "Text"],
Cell[24616, 838, 256, 7, 64, "Input"],
Cell[24875, 847, 114, 3, 64, "Input"],
Cell[24992, 852, 546, 15, 164, "Input"],
Cell[25541, 869, 114, 3, 64, "Input"],
Cell[25658, 874, 220, 6, 38, "Input"],
Cell[25881, 882, 75, 1, 38, "Input"],
Cell[25959, 885, 214, 6, 38, "Input"],
Cell[26176, 893, 75, 1, 38, "Input"],
Cell[26254, 896, 218, 6, 38, "Input"],
Cell[26475, 904, 353, 9, 64, "Input"],
Cell[26831, 915, 344, 7, 38, "Input"],
Cell[27178, 924, 286, 7, 38, "Input"],
Cell[27467, 933, 371, 7, 38, "Input"],
Cell[27841, 942, 92, 1, 38, "Input"],
Cell[27936, 945, 75, 1, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28048, 951, 42, 0, 65, "Subtitle"],
Cell[28093, 953, 93, 1, 38, "Input"],
Cell[28189, 956, 66, 0, 38, "Input"],
Cell[28258, 958, 397, 12, 38, "Input"],
Cell[28658, 972, 50, 1, 38, "Input"],
Cell[28711, 975, 314, 12, 85, "Text"],
Cell[29028, 989, 28, 0, 38, "Input"],
Cell[29059, 991, 70, 1, 38, "Input"],
Cell[29132, 994, 146, 4, 38, "Input"],
Cell[29281, 1000, 147, 4, 38, "Input"],
Cell[29431, 1006, 146, 4, 64, "Input"],
Cell[29580, 1012, 50, 1, 38, "Input"],
Cell[29633, 1015, 102, 2, 64, "Input"],
Cell[29738, 1019, 86, 2, 64, "Input"],
Cell[29827, 1023, 31, 0, 38, "Input"],
Cell[29861, 1025, 86, 2, 64, "Input"],
Cell[29950, 1029, 108, 4, 60, "Input"],
Cell[30061, 1035, 213, 5, 38, "Input"],
Cell[30277, 1042, 79, 2, 38, "Input"],
Cell[30359, 1046, 268, 7, 64, "Input"],
Cell[30630, 1055, 70, 1, 38, "Input"],
Cell[30703, 1058, 302, 6, 64, "Input"],
Cell[31008, 1066, 262, 6, 38, "Input"],
Cell[31273, 1074, 73, 0, 38, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
