(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     94178,       2884]
NotebookOptionsPosition[     47723,       1799]
NotebookOutlinePosition[     84953,       2612]
CellTagsIndexPosition[     84910,       2609]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["MathCode F90",
 FontWeight->"Bold",
 FontSlant->"Italic"]], "Title"],

Cell["- an overview and introduction", "Subtitle"],

Cell["\<\
Copyright \[Copyright] MathCore Engineering AB 1999-2004\
\>", "Copyright"],

Cell[CellGroupData[{

Cell["Abstract", "Section"],

Cell[TextData[{
 "This notebook gives a basic introduction to the third-party application \
package ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 that generates optimized F90 code from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " programs. We demonstrate the basic commands for generating, compiling, and \
installing F90 code into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Furthermore, the subset of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands that can be translated to F90 will be described. The objective \
with this notebook is to give a brief introduction to ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 and to describe what can be done and what cannot be done with ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "What is ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 "?"
}], "Section"],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 is an application package for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that generates optimized ",
 "F90",
 " code for ",
 StyleBox["numerical computations",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[".",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Compiled code can easily be called from within ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Optionally, stand-alone code can be generated (i.e. code that can be \
executed independent of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Increase in performance up to 1000 times for some computations.\
\>", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "External libraries of C, C++, and Fortran77 code can easily be connected \
and called from within ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "(depending on product version)."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell["Extended functionality for extraction of parts of matrices.", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " turns ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " into a powerful environment for prototyping of advanced numerical \
algorithms for production code development."
}], "Text",
 CellDingbat->None,
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->0,
 Background->GrayLevel[0.666667]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Who can benefit from ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 "?"
}], "Section"],

Cell[TextData[{
 "Users that are using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as an environment for ",
 StyleBox["developing",
  FontSlant->"Italic"],
 " applications and then want to automatically generate efficient ",
 "F90",
 " code for usage in large software systems: generation of",
 StyleBox[" embedded code",
  FontWeight->"Bold"],
 ". "
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Users that would like to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as an ",
 StyleBox["interface",
  FontWeight->"Bold"],
 " to old function libraries or single programs written in Fortran, C, or C++."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Users that would like to write ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages for numerical computations and then compile them to executables \
for ",
 StyleBox["proprietary reasons",
  FontWeight->"Bold"],
 " and/or for ",
 StyleBox["easy distribution",
  FontWeight->"Bold"],
 ".  "
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Users that would like to take advantage of the excellent ",
 StyleBox["prototyping environment",
  FontWeight->"Bold"],
 " in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " but also have easy access to special purpose routines already written in \
C, C++, or Fortran."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Users that have ",
 StyleBox["performance",
  FontWeight->"Bold"],
 " ",
 StyleBox["problems",
  FontWeight->"Bold"],
 " e.g. due to very large data files or functions that are computationally \
expensive to compute."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic Usage", "Section"],

Cell["Load the package", "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Since a number of temporary files will be generated by ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " we create a temporary directory and set this to the current working \
directory."
}], "Text"],

Cell["SetDirectory[$MCRoot<>\"/DemosF90/Overview\"];", "Input"],

Cell["\<\
Define a simple function but add type information about argument and return \
value (blue color)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     StyleBox["Real",
      FontColor->RGBColor[0, 0, 1]], " ", "x_"}], "]"}], 
   StyleBox["\[Rule]",
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["Real",
    FontColor->RGBColor[0, 0, 1]]}], ":=", 
  FractionBox[
   RowBox[{"Sin", "[", "x", "]"}], 
   RowBox[{"1", "+", 
    SuperscriptBox["x", "2"]}]]}]], "Input"],

Cell["The function can be used a usual", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}]}], "]"}]], "Input"],

Cell["Generate F90 code and compile it to an executable file", "Text"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", "]"}]], "Input"],

Cell[TextData[{
 "The generated executable is connected to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell["Now, the executable file is used in computations instead", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}]}], "]"}]], "Input"],

Cell["We take a look at the generated F90 file", "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<Global.f90\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Uninstall the executable, remove the temporary files, and remove the \
function ",
 StyleBox["f",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CleanMathCodeFiles", "[", 
   RowBox[{
    RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
    RowBox[{"CleanAllBut", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Remove", "[", "f", "]"}], ";"}]}], "Input"],

Cell["\<\
Hence, at the very basic level the MathCode user only have to\
\>", "Text",
 CellDingbat->None],

Cell["Add type information (function argument and return value)", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Build the ",
 "F90",
 " code using ",
 StyleBox["BuildCode[]",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Install the executable file using ",
 StyleBox["InstallCode[]",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Type Declarations", "Section"],

Cell[TextData[{
 "To be able to generate efficient F90 code the types of function arguments \
and return values has to be specified. The basic types used by ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " are"
}], "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Real", ",", "Integer", ",", "Null"}], "}"}]], "Input",
 Evaluatable->False],

Cell["but also vector- and matrix types of different formats", "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Real", "[", "5", "]"}], ",", 
   RowBox[{"Real", "[", 
    RowBox[{"3", ",", "4"}], "]"}], ",", " ", 
   RowBox[{"Real", "[", "_", "]"}], ",", 
   RowBox[{"Integer", "[", 
    RowBox[{"m", ",", "n"}], "]"}], ",", " ", 
   RowBox[{"Integer", "[", 
    RowBox[{"2", ",", "3", ",", "n_"}], "]"}]}], "}"}]], "Input",
 Evaluatable->False],

Cell["\<\
Type declarations can be given in essentially two different ways:\
\>", "Text"],

Cell["Directly in the function definition:", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     StyleBox["Real",
      FontColor->RGBColor[0, 0, 1]], " ", "x_"}], "]"}], 
   StyleBox["\[Rule]",
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["Real",
    FontColor->RGBColor[0, 0, 1]]}], ":=", 
  SuperscriptBox["x", "2"]}]], "Input",
 Evaluatable->False],

Cell["In a separate command:", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], ":=", 
  RowBox[{"Sin", " ", "[", "x", "]"}]}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{
  StyleBox["Declare",
   FontColor->RGBColor[0, 0, 1]], "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{
     StyleBox["Real",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], "x_"}], "]"}], 
   StyleBox["\[Rule]",
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["Real",
    FontColor->RGBColor[0, 0, 1]]}], "]"}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 "The latter construction can be useful if one wants to ",
 StyleBox["separate",
  FontSlant->"Italic"],
 " already existing ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code with the type information needed to be able to generate F90 code \
using ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Compilable Subset", "Section"],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 generates efficient ",
 "F90",
 " code for a ",
 StyleBox["subset",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 Background->GrayLevel[0.666667]],

Cell[TextData[{
 "A necessary condition for using ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " to generate code for a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function is that the input and output are numerical entities such as \
vectors or matrices of integers or real numbers. "
}], "Text"],

Cell[TextData[{
 "Code for intermediate symbolic computations can be generated if ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can evaluate these computations at compile time.  "
}], "Text"],

Cell[TextData[{
 "The subset of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language that MathCode ",
 "F90",
 " can handle is denotet the \"compilable subset\". The following list gives \
a brief overview and characterization of this subset"
}], "Text"],

Cell["\<\
Statically typed functions where the types of function arguments and return \
values are given by the above types.\
\>", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Scoping constructs:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox["\n\tBeginPackage[], EndPackage[],\n\tModule[], Block[], With[]",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Procedural constructs:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n\tFor[], While[], If[], Which[], Do[]"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Lists and tables:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n\tList[], Table[], Array[], Range[], IdentityMatrix[]"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Size functions:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n\tDimensions[], Length[]"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 "Arithmetic and logic expressions e.g.:\t\n\t",
 StyleBox["+, -, *, /, ==, !=, >, !, &&, ||, ...",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Elementary",
  FontFamily->"Times New Roman"],
 " functions e.g.:",
 StyleBox["\n\tSin[], Exp[], ArcSin[], Sqrt[], ...\n",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["and others e.g.:",
  FontFamily->"Times New Roman"],
 StyleBox["\n\tRound[], Max[], Cross[], Transpose[], Dot[], ... ",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Constants:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox["\n\t",
  FontFamily->"Times New Roman"],
 "True, False, E, Pi"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Assignments:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n:=, ="
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Functional commands:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n\tMap[], Apply[]"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["Some special commands:",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 "\n\tSum[], Product[]"
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 "A complete listing of the compilable subset can be found in the ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " manual or at our homepage ",
 StyleBox[ButtonBox["www.mathcore.com",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mathcore.com"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1],
  Background->None],
 "."
}], "Text"],

Cell[TextData[{
 "Functions not in the compilable subset can be used in external code by \
call-backs to ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 " see below for an example."
}], "Text"],

Cell["\<\
Examples of functions that are not a part of the compilable subset:\
\>", "Text"],

Cell["\<\
\tIntegrate[], Solve[], FindRoot[], LinearSolve[], Expand[], Factor[]\
\>", "Text",
 FontFamily->"Courier",
 FontWeight->"Bold"],

Cell[TextData[{
 "These function can be used if ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can evaluate them at compile time to expressions that belong to the \
\"compilable subset\"."
}], "Text"],

Cell[CellGroupData[{

Cell["Enlargement of the compilable subset", "Subsection"],

Cell[CellGroupData[{

Cell["Symbolic expansion of function bodies", "Subsubsection"],

Cell[TextData[{
 "Functions not entirely written using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code in the compilable subset, but whose definitions can be evaluated \
symbolically to expressions that belongs to the compilable subset, can be \
handled by ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"Real", " ", "a_"}], ",", " ", 
     RowBox[{"Real", " ", "b_"}]}], "]"}], "\[Rule]", "Real"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"x", " ", 
     RowBox[{"Sin", "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "a", ",", "b"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"1.", ",", "2."}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell["Generate F90 code and compile it to an executable file", "Text"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", 
  RowBox[{"EvaluateFunctions", "\[Rule]", 
   RowBox[{"{", "f", "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "The option EvaluateFunctions tells ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " to let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expand the function body as much as possible. Everything works fine since \
the result belongs to the compilable subset"
}], "Text"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "a", ",", "b"}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "The generated executable is connected to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"1.", ",", "2."}], "]"}]], "Input"],

Cell[TextData[{
 "Uninstall the executable, remove the temporary files, and remove the \
function ",
 StyleBox["f",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CleanMathCodeFiles", "[", 
   RowBox[{
    RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
    RowBox[{"CleanAllBut", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Remove", "[", "f", "]"}], ";"}]}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Features", "Section"],

Cell[TextData[{
 "In this section we briefly describe some more features of ",
 StyleBox["MathCode",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["Common subexpession elimination", "Subsubsection"],

Cell[TextData[{
 "Consider the following function whose definition contains a number of \
common subexpressions (e.g. ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"1", "+", 
     SuperscriptBox["x", "2"]}],
    FontColor->RGBColor[1, 0, 0]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox[
     StyleBox[
      RowBox[{"1", "+", 
       SuperscriptBox["x", "2"]}],
      FontColor->RGBColor[1, 0, 0]]],
    FontColor->RGBColor[0, 0, 1]], TraditionalForm]]],
 ")."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"Real", " ", "x_"}], "]"}], "\[Rule]", "Real"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"x", " ", 
     RowBox[{"Cos", "[", "x", "]"}], " ", 
     RowBox[{"Cos", "[", 
      StyleBox[
       SqrtBox[
        StyleBox[
         RowBox[{"1", "+", 
          SuperscriptBox["x", "2"]}],
         FontColor->RGBColor[1, 0, 0]]],
       FontColor->RGBColor[0, 0, 1]], "]"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       StyleBox[
        RowBox[{"1", "+", 
         SuperscriptBox["x", "2"]}],
        FontColor->RGBColor[1, 0, 0]], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "x", "]"}], "2"]}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "x", " ", 
     RowBox[{"Cos", "[", "x", "]"}], " ", 
     RowBox[{"Sin", "[", 
      StyleBox[
       SqrtBox[
        StyleBox[
         RowBox[{"1", "+", 
          SuperscriptBox["x", "2"]}],
         FontColor->RGBColor[1, 0, 0]]],
       FontColor->RGBColor[0, 0, 1]], "]"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       StyleBox[
        RowBox[{"1", "+", 
         SuperscriptBox["x", "2"]}],
        FontColor->RGBColor[1, 0, 0]], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "x", "]"}], "2"]}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
     RowBox[{"Sin", "[", "x", "]"}], " ", 
     RowBox[{"Sin", "[", 
      StyleBox[
       SqrtBox[
        StyleBox[
         RowBox[{"1", "+", 
          SuperscriptBox["x", "2"]}],
         FontColor->RGBColor[1, 0, 0]]],
       FontColor->RGBColor[0, 0, 1]], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      StyleBox[
       RowBox[{"1", "+", 
        SuperscriptBox["x", "2"]}],
       FontColor->RGBColor[1, 0, 0]], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "x", "]"}], "2"]}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], " ", 
     RowBox[{"Sin", "[", 
      StyleBox[
       SqrtBox[
        StyleBox[
         RowBox[{"1", "+", 
          SuperscriptBox["x", "2"]}],
         FontColor->RGBColor[1, 0, 0]]],
       FontColor->RGBColor[0, 0, 1]], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      StyleBox[
       RowBox[{"1", "+", 
        SuperscriptBox["x", "2"]}],
       FontColor->RGBColor[1, 0, 0]], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "x", "]"}], "2"]}], ")"}]}]]}]}]], "Input"],

Cell["\<\
There are algorithms to evaluate functions containing common subexpressions \
very efficiently. The basic idea is to evaluate common subexpressions only \
once and put the results in temporary variables.\
\>", "Text"],

Cell["We plot the function", "Text"],

Cell[BoxData[
 RowBox[{"pl1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"g", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "We can tell ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " to do Common Subexpression Elimination (CSE) by the option \
EvaluateFunctions to CompileCode[ ] or BuildCode[ ]."
}], "Text"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", 
  RowBox[{"EvaluateFunctions", "\[Rule]", 
   RowBox[{"{", "g", "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "The generated executable is connected to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell["and we plot the externally evaluated function", "Text"],

Cell[BoxData[
 RowBox[{"pl2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"g", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}]], "Input"],

Cell["We take a look at the generated F90 file", "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<Global.f90\>\"", "]"}]], "Input"],

Cell["\<\
Note how the computation of the function has been divided into small \
subexpressions that are only evaluated once and then stored in temporary \
variables for future use. This gives very efficient code for large functions!\
\
\>", "Text"],

Cell[TextData[{
 "Uninstall the executable, remove the temporary files, and remove the \
function ",
 StyleBox["g",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CleanMathCodeFiles", "[", 
   RowBox[{
    RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
    RowBox[{"CleanAllBut", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Remove", "[", "g", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stand-Alone Code", "Subsubsection"],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 can be used to generate ",
 "F90",
 " programs that can be executed independently of ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 " that is to produce stand-alone programs. We define a simple function that \
prints something as result (hence, return type ",
 StyleBox["Null",
  FontFamily->"Courier"],
 ")"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"Real", " ", "x_"}], "]"}], "\[Rule]", "Null"}], ":=", 
  RowBox[{"Print", "[", 
   SuperscriptBox["x", "2"], "]"}]}]], "Input"],

Cell[TextData[{
 "The option ",
 StyleBox["MainFileAndFunction",
  FontFamily->"Times New Roman"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "is used to specify the main-file. The functions defined in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " must have the prefix Global_T (",
 StyleBox["packagename",
  FontSlant->"Italic"],
 "_T in general) to be recognized in the main file."
}], "Text"],

Cell[BoxData[
 RowBox[{"CompilePackage", "[", 
  RowBox[{
  "MainFileAndFunction", "\[Rule]", 
   "\"\<\n\t\t\tcall f(1.2_mc_real)\\n\n\>\""}], "]"}]], "Input"],

Cell["The stand-alone executable is generated", "Text"],

Cell[BoxData[
 RowBox[{"MakeBinary", "[", 
  RowBox[{"StandAloneExecutable", "\[Rule]", "True"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Run", "[", "\"\<start cmd\>\"", "]"}]], "Input"],

Cell["\<\
We run the program \"Global\" and put the output in the file named result.txt\
\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", 
   RowBox[{
    RowBox[{"ToFileName", "[", 
     RowBox[{"\"\<.\>\"", ",", "\"\<Global.exe\>\""}], "]"}], "<>", 
    "\"\< >result.txt\>\""}], "]"}], ";"}]], "Input"],

Cell["The content of result.txt", "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<result.txt\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Uninstall the executable, remove the temporary files, and remove the \
function ",
 StyleBox["f",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CleanMathCodeFiles", "[", 
   RowBox[{
    RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
    RowBox[{"CleanAllBut", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Remove", "[", "f", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extended matrix operations", "Subsubsection"],

Cell["\<\
When dealing with matrices it is very convenient to have short notation for \
part extraction. The functionality of Part[] or [[ ]] has been extended to \
obtain this.\
\>", "Text"],

Cell["\<\
Consider the following 5\[Cross]5 matrix:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"a", "[", 
      RowBox[{"i", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"A", "//", "MatrixForm"}]}]], "Input"],

Cell["We extract row 2 to 4", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "\[LeftDoubleBracket]", 
   RowBox[{"2", "|", "4"}], "\[RightDoubleBracket]"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell["\<\
We extract the elements in all rows which also belongs to column 3 and higher\
\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "\[LeftDoubleBracket]", 
   RowBox[{"_", ",", 
    RowBox[{"3", "|", "_"}]}], "\[RightDoubleBracket]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[TextData[{
 "We can assign values to a submatrix of ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "\[LeftDoubleBracket]", 
    RowBox[{
     RowBox[{"2", "|", "3"}], ",", 
     RowBox[{"2", "|", "3"}]}], "\[RightDoubleBracket]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"A", " ", "//", " ", "MatrixForm"}]], "Input"],

Cell["All these operations belongs to the compilable subset.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Code Generation from a Package", "Section"],

Cell["\<\
In this section we generate code for a package called MySurface. The example \
is similar to what is shown in the SinSurface.nb demo notebook.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The Package", "Subsection"],

Cell[CellGroupData[{

Cell["Beginning of Package", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BeginPackage", "[", 
     RowBox[{"\"\<MySurface`\>\"", ",", 
      RowBox[{"{", "MathCodeContexts", "}"}]}], "]"}], ";"}], "\n", 
   RowBox[{"Off", "[", 
    RowBox[{"General", "::", "\"\<spell1\>\""}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "\"\<MySurface`*\>\"", "]"}], ";"}]}], 
  " "}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exported Symbols", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<MySurface`\>\"", "]"}], ";"}], "\n", 
 RowBox[{"\t", 
  RowBox[{"xyMatrix", ";"}]}], "\n", 
 RowBox[{"\t", 
  RowBox[{"sin", ";"}]}], "\n", 
 RowBox[{"\t", 
  RowBox[{"cos", ";"}]}], "\n", 
 RowBox[{"\t", 
  RowBox[{"arcTan", ";"}]}], "\n", 
 RowBox[{"\t", 
  RowBox[{"sinxy", ";"}]}], "\n", 
 RowBox[{"\t", 
  RowBox[{"computeGridValues", ";"}]}], "\n", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compilation Options", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCompilationOptions", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"EvaluateFunctions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"sin", ",", "cos", ",", "arcTan"}], "}"}]}], ",", "\n", "\t", 
    RowBox[{"CallBackFunctions", "\[Rule]", 
     RowBox[{"{", "FresnelS", "}"}]}], ",", "\n", "\t", 
    RowBox[{"StandAloneExecutable", "\[Rule]", "True"}], ",", "\n", "\t", 
    RowBox[{
    "MainFileAndFunction", "\[Rule]", 
     "\"\<\ninteger :: i\\n\ninteger ::j\\n\ndo i=-5,5\\n\ndo j=-5,5\\n\n\
print *,sinxy(0.4_mc_real*i,0.4_mc_real*j)\\n\nend do\\n\nprint *,\\\"***\\\"\
\\n\nend do\\n\n\>\""}]}], "\n", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private Context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Begin", "[", "\"\<MySurface`Private`\>\"", "]"}], ";"}]], "Input"],

Cell["A global variable.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Declare", "[", " ", 
   RowBox[{
    RowBox[{"Real", "[", 
     RowBox[{"21", ",", "21"}], "]"}], " ", "xyMatrix"}], " ", "]"}], 
  ";"}]], "Input"],

Cell[TextData[{
 "An function that have to be computed by a call-back to ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Declare", "[", 
  RowBox[{
   RowBox[{"FresnelS", "[", 
    RowBox[{"Real", " ", "x_"}], "]"}], "\[Rule]", "Real"}], "]"}]], "Input"],

Cell[TextData[{
 "A number of functions with right-hand-sides (rhs) not in the compilable \
subset. However, the rhs can be evaluated by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to expressions that belong to the compilable subset."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sin", "[", 
    RowBox[{"Real", " ", "x_"}], " ", "]"}], "\[Rule]", "Real"}], ":=", 
  RowBox[{
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "z", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}], " ", "/.", 
   " ", 
   RowBox[{"z", " ", "\[Rule]", " ", "x", " "}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"cos", "[", 
    RowBox[{"Real", " ", "x_"}], " ", "]"}], "\[Rule]", "Real"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"sin", "[", "z", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "x"}], "}"}]}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"arcTan", "[", 
    RowBox[{
     RowBox[{"Real", " ", "x_"}], ",", 
     RowBox[{"Real", " ", "y_"}]}], "]"}], "\[Rule]", "Real"}], ":=", " ", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"x", "<", "0"}], ",", "Pi", ",", "0"}], "]"}], "+", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"x", "==", "0"}], ",", 
     RowBox[{
      RowBox[{"Sign", "[", "y", "]"}], "*", 
      RowBox[{"Pi", "/", "2"}]}], ",", " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"y", "/", "x"}], "]"}]}], " ", "]"}]}]}]}], "Input"],

Cell["The main function", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"sinxy", "[", 
     RowBox[{
      RowBox[{"Real", " ", "x_"}], ",", 
      RowBox[{"Real", " ", "y_"}]}], "]"}], "\[Rule]", "Real"}], ":=", " ", 
   "\n", "\t", 
   RowBox[{"Module", "[", "\n", "\t\t", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{"Real", " ", 
       RowBox[{"{", 
        RowBox[{"r", ",", "xx", ",", "yy"}], "}"}]}], " ", "}"}], ",", "\n", 
     "\t\t", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"xx", "=", " ", 
       RowBox[{"r", "*", 
        RowBox[{"cos", "[", 
         RowBox[{"arcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}], "]"}]}]}], ";", "\n", "\t\t", 
      RowBox[{"yy", "=", 
       RowBox[{"r", "*", 
        RowBox[{"sin", "[", 
         RowBox[{"arcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}], "]"}]}]}], ";", "\n", "\t\t", 
      RowBox[{"sin", "[", 
       RowBox[{"xx", "+", "yy"}], "]"}]}]}], "\n", "  ", "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
A function that computes function values of sinxy[ ] over a grid. A scaling \
using the FresnelS[ ] function is also performed. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"computeGridValues", "[", 
    RowBox[{"Integer", " ", "n_"}], "]"}], " ", "\[Rule]", " ", 
   RowBox[{"Real", "[", 
    RowBox[{"21", ",", " ", "21"}], "]"}]}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Integer", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "j", ",", " ", "k"}], "}"}]}], "}"}], ",", "\n",
     "  ", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"k", "\[LessEqual]", "n"}], ",", 
       RowBox[{"xyMatrix", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"sinxy", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2."}], "+", 
             RowBox[{"0.2", "*", "i"}]}], ",", 
            RowBox[{
             RowBox[{"-", " ", "2."}], "+", 
             RowBox[{"0.2", "*", "j"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "21"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "21"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"k", "++"}]}], "]"}], ";", "\n", "\t\t", 
     RowBox[{
      RowBox[{"FresnelS", "[", "1.", "]"}], "*", "xyMatrix"}]}]}], 
   "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["End of Private Context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["End of Package", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EndPackage", "[", "]"}], ";"}], " "}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate code for all functions in the package", "Subsection"],

Cell["\<\
Generate F90 code according to the compilation options given in the package\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompilePackage", "[", "\"\<MySurface`\>\"", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["The generated code", "Subsubsection"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<MySurface.f90\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Use function expansion to avoid the auxiliary functions", "Subsection"],

Cell["\<\
Generate F90 code where the body of sinxy[ ] is symbolically expanded before \
code generation. This makes the auxiliary functions sin, cos, arcTan \
unnecessary and we choose not to compile them.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompilePackage", "[", 
   RowBox[{"\"\<MySurface`\>\"", ",", "\n", "\t", 
    RowBox[{"EvaluateFunctions", "\[Rule]", 
     RowBox[{"{", "sinxy", "}"}]}], ",", "\n", "\t", 
    RowBox[{"UnCompiledFunctions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"sin", ",", "cos", ",", "arcTan"}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["The generated code", "Subsubsection"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<MySurface.f90\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate Stand-Alone Code", "Subsection"],

Cell[TextData[{
 "Generate ",
 "F90",
 " code without code for FresnelS[ ] and computeGridValues[ ] since the main \
function does not use these (FresnalS[ ] cannot be evaluated without \
call-backs to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ")."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompilePackage", "[", 
   RowBox[{"\"\<MySurface`\>\"", ",", "\n", "\t", 
    RowBox[{"CallBackFunctions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", "\n", "\t", 
    RowBox[{"UnCompiledFunctions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FresnelS", ",", "computeGridValues"}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"MakeBinary", "[", "]"}]], "Input"],

Cell["\<\
We run the external program and put the result in a file: res.txt\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Run", "[", 
   RowBox[{
    RowBox[{"ToFileName", "[", 
     RowBox[{"\"\<.\>\"", ",", "\"\<MySurface.exe\>\""}], "]"}], "<>", 
    "\"\< > res.txt\>\""}], "]"}], ";"}]], "Input"],

Cell["The contents of res.txt", "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<res.txt\>\"", "]"}]], "Input"],

Cell["\<\
and a plot of the result (note that \"\\n\" and space before \"***\" )\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{"\"\<res.txt\>\"", ",", "Number", ",", 
    RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
    RowBox[{
     StyleBox["RecordSeparators", "MR"], " ", "\[Rule]", " ", 
     "\"\<\\n ***\>\""}]}], "]"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["The generated code", "Subsubsection"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<MySurface.f90\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Macro rules", "Subsection"],

Cell[TextData[{
 "Instead of using call-backs to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to evaluate functions not in the compilable subset so called macro rules \
can be used to replace these functions with compilable expressions. We \
illustrate this by substituting the FresbelS[ ] function above with a \
polynomial."
}], "Text"],

Cell["Generate some data", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"FresnelS", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2", ",", ".1"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
Define the function ownFresnelS[ ] whose right hand side is a polynomial fit \
of 10th degree to the data with \"small\" terms removed\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ownFresnelS", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"Fit", "[", 
    RowBox[{"data", ",", 
     SuperscriptBox["x", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "10"}], "]"}]], ",", "x"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell["We check the result", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FresnelS", "[", "x", "]"}], ",", 
     RowBox[{"ownFresnelS", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "]"}]], "Input"],

Cell["Generate F90 code with ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompilePackage", "[", 
   RowBox[{"\"\<MySurface`\>\"", ",", "\n", "\t", 
    RowBox[{"CallBackFunctions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", "\n", "\t", 
    RowBox[{"MacroRules", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FresnelS", "[", "x_", "]"}], "\[Rule]", 
       RowBox[{"ownFresnelS", "[", "x", "]"}]}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["The generated code", "Subsubsection"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<MySurface.f90\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clean-up", "Section"],

Cell["\<\
Uninstall the executable, remove the temporary files, and remove the \
functions in the MySurface` package.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CleanMathCodeFiles", "[", 
   RowBox[{
    RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
    RowBox[{"CleanAllBut", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"Remove", "::", "rmnsm"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remove", "[", "\"\<MySurface`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{"Remove", "::", "rmnsm"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"DeleteFile", "::", "nffil"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<res.txt\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeleteFile", "[", "\"\<result.txt\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{"DeleteFile", "::", "nffil"}], "]"}], ";"}]}], "Input"],

Cell["Delete the temporary directory and all files it contains.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusions", "Section"],

Cell[TextData[{
 "Simple usage: the most basic usage of ",
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 StyleBox[" ",
  FontSlant->"Italic"],
 "can be summarized by three steps\n\t1)  Add type declarations\n\t2)  \
BuildCode[ ] generates ",
 "F90",
 " code and an executable program\n\t3)  InstallCode[ ] connects the \
executable program to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90",
 " provides an easy way of calling external programs without knowledge about ",
 StyleBox["MathLink.",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "The combination of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and",
 StyleBox[" MathCode ",
  FontSlant->"Italic"],
 "F90",
 " is an excellent tool for prototyping of numerical algorithms."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Speeds up large numerical computations that can be performed by compiled \
code outside ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["MathCode ",
  FontSlant->"Italic"],
 "F90 is an application package for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that generates optimized ",
 "F90",
 " code for ",
 StyleBox["numerical computations",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[".",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell["Boost in performance for large numerical computations.", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Transparent calling of compiled code from within ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " "
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " independent stand-alone code and programs can be generated "
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "Keep track of the compilable subset of ",
 StyleBox["Mathematica\n- Procedural programming constructs ",
  FontSlant->"Italic"],
 "(For, While, Do, If, ...)",
 StyleBox["\n- Elementary functions ",
  FontSlant->"Italic"],
 "(Sin, Exp, Log, ...)",
 StyleBox["\n- Arithmetic and logic expressions ",
  FontSlant->"Italic"],
 "(+,-,*,/,||,<,!=,...) \n- Map, Apply, List, Table, Array, Module, Sum, \
Product, Dot, Max, Transpose, DiagonalMatrix, ..."
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "How to use functions which does not belong to the compilable subset?\n",
 StyleBox["- Symbolic evaluation\n- Call-backs to Mathematica\n- Use external \
code\n- Reimplement the function using functions in the compilable subset",
  FontSlant->"Italic"]
}], "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Simple usage: Type declarations, BuildCode[ ], InstallCode[ ]\
\>", "Text",
 CellDingbat->"\[FilledSmallCircle]",
 CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{761, 865},
WindowMargins->{{36, Automatic}, {10, Automatic}},
ShowSelection->True,
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageHeaderLines -> {True, True}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontSize -> 
             34, FontColor -> GrayLevel[1], Background -> RGBColor[0, 0, 1]], 
            
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 0}, FontSize -> 
             44], 
            Cell[
             StyleData["Title", "Condensed"], CellMargins -> {{0, 0}, {0, 0}},
              FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24, FontTracking -> "Plain", Background -> 
             GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 3}, ParagraphIndent -> -96, CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 6}, 
             ParagraphIndent -> -157, FontSize -> 30], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -78, 
             FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -85, 
             FontSize -> 16, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {30, 10}}, PageBreakBelow -> False, 
             CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{8, 10}, {40, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{9, 10}, {50, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {4, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 6, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold", 
             FontColor -> RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{10, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, FontSize -> 14, FontTracking -> 
             "Plain", FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], 
             CellMargins -> {{12, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{11, 10}, {8, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {4, 40}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{29, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{22, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{21, 0}, {4, 20}}, FontSize -> 11]}, Open]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Text", FontFamily -> "Times"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {4, 4}},
              LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{9, 0}, {4, 4}}, 
             ParagraphSpacing -> {0, 6}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 6}, 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {2, 2}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{9, 0}, {4, 4}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[1, 1, 0]], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{44, 0}, {6, 6}},
              Background -> GrayLevel[0.8]]}, Closed]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{3, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Output", Background -> 
             RGBColor[1, 0.900008, 0.900008]], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{62, Inherited}, {12, 5}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{40, Inherited}, {4, 1}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{44, 0}, {6, 2}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             CellMargins -> {{52, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {175, 175}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 11, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 8], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {2, 10}}, FontSize -> 16, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Author", "Presentation"], 
             CellMargins -> {{12, 10}, {2, 12}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 20], 
            Cell[
             StyleData["Author", "Condensed"], 
             CellMargins -> {{8, 10}, {1, 4}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{9, 0}, {4, 12}}, ParagraphSpacing -> {0, 6}, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Copyright"], ShowCellBracket -> False, 
             CellMargins -> {{10, 10}, {40, 2}}, FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Presentation"], 
             CellMargins -> {{12, 10}, {50, 2}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["Copyright", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 1}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Printout"], 
             CellMargins -> {{9, 0}, {72, 4}}, FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Example"], CellMargins -> {{12, 10}, {5, 12}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Example", FontFamily -> "Times", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Example", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 20}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Example", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Example", "Printout"], 
             CellMargins -> {{9, 0}, {4, 10}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Definition"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Definition", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Definition", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Definition", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Definition", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.6]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Theorem"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Theorem", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Theorem", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Theorem", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Theorem", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.4]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseMain"], CellFrame -> {{6, 0}, {0, 1}}, 
             CellMargins -> {{12, Inherited}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0.571389, 0.19675, 0.570504], 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 16, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["ExerciseMain", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["ExerciseMain", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["ExerciseMain", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, CellFrameColor -> 
             GrayLevel[0.500008], FontSize -> 14, FontTracking -> "Plain", 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> "\[FilledDownTriangle]", 
             CellMargins -> {{23, Inherited}, {4, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Exercise", "Presentation"], 
             CellMargins -> {{33, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Exercise", "Condensed"], 
             CellMargins -> {{17, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, CellDingbat -> None, 
             CellMargins -> {{9, 0}, {6, 20}}, FontSize -> 11, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseText"], CellMargins -> {{62, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExcersiceText", FontFamily -> "Times"], 
            Cell[
             StyleData["ExerciseText", "Presentation"], 
             CellMargins -> {{74, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["ExerciseText", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 2}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["ExerciseText", "Printout"], 
             CellMargins -> {{54, 0}, {4, 4}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Itemize"], CellDingbat -> "\[FilledSmallCircle]", 
             CellMargins -> {{65, Inherited}, {8, 8}}, FontFamily -> "Times", 
             FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Itemize", "Presentation"], 
             CellMargins -> {{Inherited, 10}, {8, 12}}, LineSpacing -> {1, 0},
              FontSize -> 18], 
            Cell[
             StyleData["Itemize", "Condensed"], 
             CellMargins -> {{Inherited, Inherited}, {2, 12}}, FontSize -> 
             10], 
            Cell[
             StyleData["Itemize", "Printout"], 
             CellMargins -> {{Inherited, 0}, {4, 20}}, FontSize -> 11]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayCode"], CellFrame -> 2, 
             CellMargins -> {{52, 10}, {8, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> True, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             FontWeight -> "Bold", Background -> RGBColor[1, 1, 0]], 
            Cell[
             StyleData["DisplayCode", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["DisplayCode", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["DisplayCode", "Printout"], 
             CellMargins -> {{44, 0}, {6, 6}}, Background -> GrayLevel[0.8]]},
            Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{62, 10}, {2, 10}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 18], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{62, 10}, {2, 10}},
              AutoSpacing -> False, ScriptBaselineShifts -> {0.6, Automatic}, 
             ScriptLevel -> 1, SingleLetterItalics -> False, ZeroWidthTimes -> 
             True], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{12, 10}, {Inherited, 6}}, 
             FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{13, 30}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{9, 0}, {Inherited, 4}}, FontSize -> 9.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section"], 
         Cell[
         "The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{62, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Condensed"], 
             CellMargins -> {{52, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["NumberedFigure"]}]], None}}, CounterIncrements -> 
             "NumberedFigure", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedFigure", "Presentation"]], 
            Cell[
             StyleData["NumberedFigure", "Condensed"]], 
            Cell[
             StyleData["NumberedFigure", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Table ", 
                   CounterBox["NumberedTable"]}]], None}}, TextAlignment -> 
             Center, CounterIncrements -> "NumberedTable", 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedTable", "Presentation"]], 
            Cell[
             StyleData["NumberedTable", "Condensed"]], 
            Cell[
             StyleData["NumberedTable", "Printout"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 6], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontWeight -> "Bold"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]]}, Closed]]},
      Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (32-bit) (November 7, 2010)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 92, 2, 55, "Title"],
Cell[652, 24, 50, 0, 37, "Subtitle"],
Cell[705, 26, 85, 2, 54, "Copyright"],
Cell[CellGroupData[{
Cell[815, 32, 27, 0, 54, "Section"],
Cell[845, 34, 810, 24, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1692, 63, 103, 6, 54, "Section"],
Cell[1798, 71, 431, 16, 25, "Text"],
Cell[2232, 89, 223, 6, 25, "Text"],
Cell[2458, 97, 277, 8, 25, "Text"],
Cell[2738, 107, 182, 4, 25, "Text"],
Cell[2923, 113, 310, 8, 43, "Text"],
Cell[3236, 123, 170, 2, 25, "Text"],
Cell[3409, 127, 415, 14, 59, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3861, 146, 116, 6, 54, "Section"],
Cell[3980, 154, 468, 15, 43, "Text"],
Cell[4451, 171, 343, 10, 25, "Text"],
Cell[4797, 183, 426, 14, 43, "Text"],
Cell[5226, 199, 401, 11, 43, "Text"],
Cell[5630, 212, 342, 11, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6009, 228, 30, 0, 54, "Section"],
Cell[6042, 230, 32, 0, 25, "Text"],
Cell[6077, 232, 74, 1, 48, "Input"],
Cell[6154, 235, 227, 7, 43, "Text"],
Cell[6384, 244, 63, 0, 48, "Input"],
Cell[6450, 246, 120, 3, 25, "Text"],
Cell[6573, 251, 390, 14, 64, "Input"],
Cell[6966, 267, 48, 0, 25, "Text"],
Cell[7017, 269, 197, 6, 48, "Input"],
Cell[7217, 277, 70, 0, 25, "Text"],
Cell[7290, 279, 57, 1, 48, "Input"],
Cell[7350, 282, 127, 5, 25, "Text"],
Cell[7480, 289, 77, 2, 48, "Input"],
Cell[7560, 293, 72, 0, 25, "Text"],
Cell[7635, 295, 197, 6, 48, "Input"],
Cell[7835, 303, 56, 0, 25, "Text"],
Cell[7894, 305, 79, 1, 48, "Input"],
Cell[7976, 308, 174, 6, 26, "Text"],
Cell[8153, 316, 342, 10, 89, "Input"],
Cell[8498, 328, 105, 3, 25, "Text"],
Cell[8606, 333, 168, 2, 25, "Text"],
Cell[8777, 337, 234, 9, 26, "Text"],
Cell[9014, 348, 235, 7, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9286, 360, 36, 0, 54, "Section"],
Cell[9325, 362, 234, 7, 43, "Text"],
Cell[9562, 371, 115, 3, 48, "Input",
 Evaluatable->False],
Cell[9680, 376, 70, 0, 25, "Text"],
Cell[9753, 378, 385, 11, 48, "Input",
 Evaluatable->False],
Cell[10141, 391, 89, 2, 25, "Text"],
Cell[10233, 395, 147, 2, 25, "Text"],
Cell[10383, 399, 333, 12, 48, "Input",
 Evaluatable->False],
Cell[10719, 413, 133, 2, 25, "Text"],
Cell[10855, 417, 135, 4, 48, "Input",
 Evaluatable->False],
Cell[10993, 423, 417, 15, 48, "Input",
 Evaluatable->False],
Cell[11413, 440, 348, 13, 43, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11798, 458, 40, 0, 54, "Section"],
Cell[11841, 460, 338, 16, 41, "Text"],
Cell[12182, 478, 322, 10, 43, "Text"],
Cell[12507, 490, 200, 5, 25, "Text"],
Cell[12710, 497, 269, 8, 43, "Text"],
Cell[12982, 507, 233, 5, 25, "Text"],
Cell[13218, 514, 380, 11, 87, "Text"],
Cell[13601, 527, 303, 9, 56, "Text"],
Cell[13907, 538, 314, 9, 56, "Text"],
Cell[14224, 549, 283, 9, 56, "Text"],
Cell[14510, 560, 269, 7, 56, "Text"],
Cell[14782, 569, 482, 14, 117, "Text"],
Cell[15267, 585, 322, 11, 56, "Text"],
Cell[15592, 598, 261, 9, 56, "Text"],
Cell[15856, 609, 280, 9, 56, "Text"],
Cell[16139, 620, 284, 9, 56, "Text"],
Cell[16426, 631, 406, 14, 25, "Text"],
Cell[16835, 647, 199, 6, 25, "Text"],
Cell[17037, 655, 91, 2, 25, "Text"],
Cell[17131, 659, 138, 4, 26, "Text"],
Cell[17272, 665, 208, 6, 25, "Text"],
Cell[CellGroupData[{
Cell[17505, 675, 58, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[17588, 679, 62, 0, 35, "Subsubsection"],
Cell[17653, 681, 343, 11, 43, "Text"],
Cell[17999, 694, 380, 12, 48, "Input"],
Cell[18382, 708, 79, 2, 48, "Input"],
Cell[18464, 712, 44, 1, 48, "Input"],
Cell[18511, 715, 70, 0, 25, "Text"],
Cell[18584, 717, 131, 3, 48, "Input"],
Cell[18718, 722, 308, 10, 43, "Text"],
Cell[19029, 734, 200, 6, 48, "Input"],
Cell[19232, 742, 127, 5, 25, "Text"],
Cell[19362, 749, 77, 2, 48, "Input"],
Cell[19442, 753, 79, 2, 48, "Input"],
Cell[19524, 757, 174, 6, 26, "Text"],
Cell[19701, 765, 342, 10, 89, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20104, 782, 33, 0, 54, "Section"],
Cell[20140, 784, 141, 5, 25, "Text"],
Cell[CellGroupData[{
Cell[20306, 793, 56, 0, 35, "Subsubsection"],
Cell[20365, 795, 518, 20, 32, "Text"],
Cell[20886, 817, 2756, 95, 138, "Input"],
Cell[23645, 914, 227, 4, 43, "Text"],
Cell[23875, 920, 36, 0, 25, "Text"],
Cell[23914, 922, 219, 7, 48, "Input"],
Cell[24136, 931, 217, 7, 43, "Text"],
Cell[24356, 940, 131, 3, 48, "Input"],
Cell[24490, 945, 121, 4, 25, "Text"],
Cell[24614, 951, 77, 2, 48, "Input"],
Cell[24694, 955, 61, 0, 25, "Text"],
Cell[24758, 957, 219, 7, 48, "Input"],
Cell[24980, 966, 56, 0, 25, "Text"],
Cell[25039, 968, 79, 1, 48, "Input"],
Cell[25121, 971, 249, 5, 43, "Text"],
Cell[25373, 978, 174, 6, 26, "Text"],
Cell[25550, 986, 342, 10, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25929, 1001, 41, 0, 35, "Subsubsection"],
Cell[25973, 1003, 396, 13, 43, "Text"],
Cell[26372, 1018, 197, 6, 50, "Input"],
Cell[26572, 1026, 401, 13, 43, "Text"],
Cell[26976, 1041, 160, 4, 89, "Input"],
Cell[27139, 1047, 55, 0, 25, "Text"],
Cell[27197, 1049, 114, 2, 48, "Input"],
Cell[27314, 1053, 72, 1, 48, "Input"],
Cell[27389, 1056, 103, 3, 25, "Text"],
Cell[27495, 1061, 213, 6, 48, "Input"],
Cell[27711, 1069, 41, 0, 25, "Text"],
Cell[27755, 1071, 79, 1, 48, "Input"],
Cell[27837, 1074, 174, 6, 26, "Text"],
Cell[28014, 1082, 342, 10, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28393, 1097, 51, 0, 35, "Subsubsection"],
Cell[28447, 1099, 191, 4, 43, "Text"],
Cell[28641, 1105, 65, 2, 25, "Text"],
Cell[28709, 1109, 337, 11, 48, "Input"],
Cell[29049, 1122, 37, 0, 25, "Text"],
Cell[29089, 1124, 163, 4, 48, "Input"],
Cell[29255, 1130, 103, 3, 25, "Text"],
Cell[29361, 1135, 178, 5, 48, "Input"],
Cell[29542, 1142, 126, 5, 25, "Text"],
Cell[29671, 1149, 377, 12, 48, "Input"],
Cell[30051, 1163, 69, 1, 48, "Input"],
Cell[30123, 1166, 70, 0, 25, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30242, 1172, 49, 0, 54, "Section"],
Cell[30294, 1174, 166, 3, 25, "Text"],
Cell[CellGroupData[{
Cell[30485, 1181, 33, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[30543, 1185, 45, 0, 35, "Subsubsection"],
Cell[30591, 1187, 374, 11, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31002, 1203, 41, 0, 35, "Subsubsection"],
Cell[31046, 1205, 466, 16, 189, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31549, 1226, 44, 0, 35, "Subsubsection"],
Cell[31596, 1228, 669, 14, 329, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32302, 1247, 40, 0, 35, "Subsubsection"],
Cell[32345, 1249, 101, 2, 48, "Input"],
Cell[32449, 1253, 34, 0, 25, "Text"],
Cell[32486, 1255, 183, 6, 48, "Input"],
Cell[32672, 1263, 136, 4, 25, "Text"],
Cell[32811, 1269, 157, 4, 48, "Input"],
Cell[32971, 1275, 257, 6, 43, "Text"],
Cell[33231, 1283, 1303, 41, 109, "Input"],
Cell[34537, 1326, 33, 0, 25, "Text"],
Cell[34573, 1328, 1122, 34, 189, "Input"],
Cell[35698, 1364, 152, 3, 25, "Text"],
Cell[35853, 1369, 1281, 37, 129, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37171, 1411, 47, 0, 35, "Subsubsection"],
Cell[37221, 1413, 69, 2, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37327, 1420, 39, 0, 35, "Subsubsection"],
Cell[37369, 1422, 95, 3, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37513, 1431, 68, 0, 44, "Subsection"],
Cell[37584, 1433, 99, 2, 25, "Text"],
Cell[37686, 1437, 102, 2, 48, "Input"],
Cell[CellGroupData[{
Cell[37813, 1443, 43, 0, 35, "Subsubsection"],
Cell[37859, 1445, 82, 1, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37990, 1452, 77, 0, 44, "Subsection"],
Cell[38070, 1454, 220, 4, 43, "Text"],
Cell[38293, 1460, 361, 9, 89, "Input"],
Cell[CellGroupData[{
Cell[38679, 1473, 43, 0, 35, "Subsubsection"],
Cell[38725, 1475, 82, 1, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38856, 1482, 47, 0, 44, "Subsection"],
Cell[38906, 1484, 271, 9, 43, "Text"],
Cell[39180, 1495, 356, 9, 89, "Input"],
Cell[39539, 1506, 58, 1, 48, "Input"],
Cell[39600, 1509, 89, 2, 25, "Text"],
Cell[39692, 1513, 214, 6, 48, "Input"],
Cell[39909, 1521, 39, 0, 25, "Text"],
Cell[39951, 1523, 76, 1, 48, "Input"],
Cell[40030, 1526, 94, 2, 25, "Text"],
Cell[40127, 1530, 303, 7, 48, "Input"],
Cell[CellGroupData[{
Cell[40455, 1541, 43, 0, 35, "Subsubsection"],
Cell[40501, 1543, 82, 1, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40632, 1550, 33, 0, 44, "Subsection"],
Cell[40668, 1552, 348, 8, 43, "Text"],
Cell[41019, 1562, 34, 0, 25, "Text"],
Cell[41056, 1564, 321, 11, 48, "Input"],
Cell[41380, 1577, 158, 3, 25, "Text"],
Cell[41541, 1582, 280, 9, 50, "Input"],
Cell[41824, 1593, 35, 0, 25, "Text"],
Cell[41862, 1595, 292, 9, 48, "Input"],
Cell[42157, 1606, 39, 0, 25, "Text"],
Cell[42199, 1608, 414, 11, 89, "Input"],
Cell[CellGroupData[{
Cell[42638, 1623, 43, 0, 35, "Subsubsection"],
Cell[42684, 1625, 82, 1, 48, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42827, 1633, 27, 0, 54, "Section"],
Cell[42857, 1635, 131, 3, 25, "Text"],
Cell[42991, 1640, 943, 27, 189, "Input"],
Cell[43937, 1669, 73, 0, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44047, 1674, 30, 0, 54, "Section"],
Cell[44080, 1676, 510, 16, 115, "Text"],
Cell[44593, 1694, 303, 9, 25, "Text"],
Cell[44899, 1705, 326, 11, 25, "Text"],
Cell[45228, 1718, 269, 8, 25, "Text"],
Cell[45500, 1728, 431, 16, 25, "Text"],
Cell[45934, 1746, 165, 2, 25, "Text"],
Cell[46102, 1750, 230, 7, 25, "Text"],
Cell[46335, 1759, 235, 6, 25, "Text"],
Cell[46573, 1767, 572, 14, 145, "Text"],
Cell[47148, 1783, 376, 7, 145, "Text"],
Cell[47527, 1792, 180, 4, 25, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
